#[non_exhaustive]pub struct Resources<Pins> {Show 46 fields
pub pit: Pit,
pub gpt1: Gpt,
pub gpt2: Gpt,
pub gpio1: Port,
pub gpio2: Port,
pub gpio3: Port,
pub gpio4: Port,
pub usb: Instances<1>,
pub dma: [Option<Channel>; 32],
pub srtc: Disabled,
pub snvs_lp_core: LpCore,
pub ccm: CCM,
pub ccm_analog: CCM_ANALOG,
pub dcdc: DCDC,
pub pins: Pins,
pub lpi2c1: LPI2C1,
pub lpi2c3: LPI2C3,
pub lpspi1: LPSPI1,
pub lpspi2: LPSPI2,
pub lpspi3: LPSPI3,
pub lpspi4: LPSPI4,
pub lpuart6: LPUART6,
pub lpuart4: LPUART4,
pub lpuart2: LPUART2,
pub lpuart3: LPUART3,
pub lpuart8: LPUART8,
pub lpuart1: LPUART1,
pub lpuart5: LPUART5,
pub lpuart7: LPUART7,
pub flexpwm1: Pwm,
pub flexpwm2: Pwm,
pub flexpwm3: Pwm,
pub flexpwm4: Pwm,
pub flexio1: FLEXIO1,
pub flexio2: FLEXIO2,
pub flexio3: FLEXIO3,
pub adc1: Adc,
pub adc2: Adc,
pub trng: Trng,
pub tempmon: TempMon,
pub sai1: SAI1,
pub sai2: SAI2,
pub sai3: SAI3,
pub iomuxc_gpr: IOMUXC_GPR,
pub usdhc1: USDHC1,
pub flexspi2: FLEXSPI2,
}Expand description
Resources constructed by the board.
The concrete Pins type depends on how this is constructed.
See the various *Resources aliases for more information.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.pit: PitPeriodic interrupt timer.
gpt1: GptGeneral purpose timer 1.
gpt2: GptGeneral purpose timer 2.
gpio1: PortGPIO1 port.
gpio2: PortGPIO2 port.
gpio3: PortGPIO3 port.
gpio4: PortGPIO4 port.
usb: Instances<1>USB1 instances.
Use this to construct higher-level USB drivers, or to initialize the USB logger.
dma: [Option<Channel>; 32]DMA channels.
srtc: DisabledThe secure real-time counter.
It’s initially disabled, and you may enable it in your firmware.
snvs_lp_core: LpCoreCore registers for the SNVS low-power domain.
Use this with the SRTC and other SNVS LP components.
ccm: CCMClock control module.
ccm_analog: CCM_ANALOGAnalog clock control module.
dcdc: DCDCDCDC converter
pins: PinsAll available pins.
lpi2c1: LPI2C1The register block for LPI2C1.
lpi2c3: LPI2C3The register block for LPI2C3.
lpspi1: LPSPI1The register block for LPSPI1.
lpspi2: LPSPI2The register block for LPSPI2.
lpspi3: LPSPI3The register block for LPSPI3.
lpspi4: LPSPI4The register block for LPSPI4.
lpuart6: LPUART6The register block for LPUART6.
lpuart4: LPUART4The register block for LPUART4.
lpuart2: LPUART2The register block for LPUART2.
lpuart3: LPUART3The register block for LPUART3.
lpuart8: LPUART8The register block for LPUART8.
lpuart1: LPUART1The register block for LPUART1.
lpuart5: LPUART5The register block for LPUART5.
lpuart7: LPUART7The register block for LPUART7.
flexpwm1: PwmFlexPWM1.
flexpwm2: PwmFlexPWM2.
flexpwm3: PwmFlexPWM3.
flexpwm4: PwmFlexPWM4.
flexio1: FLEXIO1The FlexIO1 register block.
flexio2: FLEXIO2The FlexIO2 register block.
flexio3: FLEXIO3The FlexIO3 register block.
adc1: AdcThe register block for ADC1.
ADC drivers constructed by board use a pre-configured clock and divisor. To change
this configuration, call release() to acquire the register block, then re-construct
the driver.
adc2: AdcThe register block for ADC2.
trng: TrngTrue random number generator.
tempmon: TempMonTemperature monitor of the core.
sai1: SAI1The register block for SAI1 (I2S audio).
SAI1 is the primary audio interface used by the Teensy Audio Shield.
sai2: SAI2The register block for SAI2.
sai3: SAI3The register block for SAI3.
iomuxc_gpr: IOMUXC_GPRThe IOMUXC general purpose register block.
usdhc1: USDHC1The USDHC1 peripheral instance.
flexspi2: FLEXSPI2The FlexSPI2 peripheral instance.