TMMResources

Type Alias TMMResources 

pub type TMMResources = Resources<Pins>;
Resources for a Teensy MicroMod.

Use tmm to construct this. The pins are specific to the Teensy MicroMod.

Aliased Type

pub struct TMMResources {
Show 46 fields pub pit: Pit, pub gpt1: Gpt, pub gpt2: Gpt, pub gpio1: Port, pub gpio2: Port, pub gpio3: Port, pub gpio4: Port, pub usb: Instances<1>, pub dma: [Option<Channel>; 32], pub srtc: Disabled, pub snvs_lp_core: Instance<RegisterBlock>, pub ccm: Instance<RegisterBlock, 0>, pub ccm_analog: Instance<RegisterBlock, 0>, pub dcdc: Instance<RegisterBlock, 0>, pub pins: Pins, pub lpi2c1: Instance<RegisterBlock, 1>, pub lpi2c3: Instance<RegisterBlock, 3>, pub lpspi1: Instance<RegisterBlock, 1>, pub lpspi2: Instance<RegisterBlock, 2>, pub lpspi3: Instance<RegisterBlock, 3>, pub lpspi4: Instance<RegisterBlock, 4>, pub lpuart6: Instance<RegisterBlock, 6>, pub lpuart4: Instance<RegisterBlock, 4>, pub lpuart2: Instance<RegisterBlock, 2>, pub lpuart3: Instance<RegisterBlock, 3>, pub lpuart8: Instance<RegisterBlock, 8>, pub lpuart1: Instance<RegisterBlock, 1>, pub lpuart5: Instance<RegisterBlock, 5>, pub lpuart7: Instance<RegisterBlock, 7>, pub flexpwm1: Pwm, pub flexpwm2: Pwm, pub flexpwm3: Pwm, pub flexpwm4: Pwm, pub flexio1: Instance<RegisterBlock, 1>, pub flexio2: Instance<RegisterBlock, 2>, pub flexio3: Instance<RegisterBlock, 3>, pub adc1: Adc, pub adc2: Adc, pub trng: Trng, pub tempmon: TempMon, pub sai1: Instance<RegisterBlock, 1>, pub sai2: Instance<RegisterBlock, 2>, pub sai3: Instance<RegisterBlock, 3>, pub iomuxc_gpr: Instance<RegisterBlock, 0>, pub usdhc1: Instance<RegisterBlock, 1>, pub flexspi2: Instance<RegisterBlock, 2>,
}

Fields

pit: Pit

Periodic interrupt timer.

gpt1: Gpt

General purpose timer 1.

gpt2: Gpt

General purpose timer 2.

gpio1: Port

GPIO1 port.

gpio2: Port

GPIO2 port.

gpio3: Port

GPIO3 port.

gpio4: Port

GPIO4 port.

usb: Instances<1>

USB1 instances.

Use this to construct higher-level USB drivers, or to initialize the USB logger.

dma: [Option<Channel>; 32]

DMA channels.

srtc: Disabled

The secure real-time counter.

It’s initially disabled, and you may enable it in your firmware.

snvs_lp_core: Instance<RegisterBlock>

Core registers for the SNVS low-power domain.

Use this with the SRTC and other SNVS LP components.

ccm: Instance<RegisterBlock, 0>

Clock control module.

ccm_analog: Instance<RegisterBlock, 0>

Analog clock control module.

dcdc: Instance<RegisterBlock, 0>

DCDC converter

pins: Pins

All available pins.

lpi2c1: Instance<RegisterBlock, 1>

The register block for LPI2C1.

lpi2c3: Instance<RegisterBlock, 3>

The register block for LPI2C3.

lpspi1: Instance<RegisterBlock, 1>

The register block for LPSPI1.

lpspi2: Instance<RegisterBlock, 2>

The register block for LPSPI2.

lpspi3: Instance<RegisterBlock, 3>

The register block for LPSPI3.

lpspi4: Instance<RegisterBlock, 4>

The register block for LPSPI4.

lpuart6: Instance<RegisterBlock, 6>

The register block for LPUART6.

lpuart4: Instance<RegisterBlock, 4>

The register block for LPUART4.

lpuart2: Instance<RegisterBlock, 2>

The register block for LPUART2.

lpuart3: Instance<RegisterBlock, 3>

The register block for LPUART3.

lpuart8: Instance<RegisterBlock, 8>

The register block for LPUART8.

lpuart1: Instance<RegisterBlock, 1>

The register block for LPUART1.

lpuart5: Instance<RegisterBlock, 5>

The register block for LPUART5.

lpuart7: Instance<RegisterBlock, 7>

The register block for LPUART7.

flexpwm1: Pwm

FlexPWM1.

flexpwm2: Pwm

FlexPWM2.

flexpwm3: Pwm

FlexPWM3.

flexpwm4: Pwm

FlexPWM4.

flexio1: Instance<RegisterBlock, 1>

The FlexIO1 register block.

flexio2: Instance<RegisterBlock, 2>

The FlexIO2 register block.

flexio3: Instance<RegisterBlock, 3>

The FlexIO3 register block.

adc1: Adc

The register block for ADC1.

ADC drivers constructed by board use a pre-configured clock and divisor. To change this configuration, call release() to acquire the register block, then re-construct the driver.

adc2: Adc

The register block for ADC2.

trng: Trng

True random number generator.

tempmon: TempMon

Temperature monitor of the core.

sai1: Instance<RegisterBlock, 1>

The register block for SAI1 (I2S audio).

SAI1 is the primary audio interface used by the Teensy Audio Shield.

sai2: Instance<RegisterBlock, 2>

The register block for SAI2.

sai3: Instance<RegisterBlock, 3>

The register block for SAI3.

iomuxc_gpr: Instance<RegisterBlock, 0>

The IOMUXC general purpose register block.

usdhc1: Instance<RegisterBlock, 1>

The USDHC1 peripheral instance.

flexspi2: Instance<RegisterBlock, 2>

The FlexSPI2 peripheral instance.